/*
 * Copyright 2021 - 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.sbm.project.resource.filter;

import org.springframework.sbm.project.resource.ProjectResourceSet;
import lombok.Getter;

import java.util.List;
import java.util.stream.Collectors;

public class GenericTypeListFilter<T> implements ProjectResourceFinder<List<T>> {

    @Getter
    private final Class<T> type;

    public GenericTypeListFilter(Class<T> type) {
        this.type = type;
    }

    @Override
    public List<T> apply(ProjectResourceSet projectResourceSet) {
        return projectResourceSet.stream()
                .filter(pr -> type.isAssignableFrom(pr.getClass()))
                .map(type::cast)
                .collect(Collectors.toList());
    }
}
